pilas.habilidades.MirarAlActor

Package pilas :: Module habilidades :: Class MirarAlActor |
[hide private]
[frames] | no frames]

# Class MirarAlActor

source code

    object --+
             |
     Habilidad --+
                 |
                MirarAlActor

"Hace que un actor rote para mirar hacia otro actor.

Instance Methods | [hide private]
__init__(self, receptor, actor_a_seguir, lado_seguimiento=270) Inicializa la habilidad. | source code
rotar(self, evento) | source code
Inherited from `Habilidad`: `actualizar`, `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| ARRIBA = `270`
| ABAJO = `90`
| IZQUIERDA = `180`
| DERECHA = `0`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, actor_a_seguir, lado_seguimiento=270) (Constructor) | source code
Inicializa la habilidad. :param receptor: Actor que aprenderá la habilidad. :param actor_a_seguir : Actor al que se desea seguir con la mirada. :param lado_seguimiento: Establece el lado del actor que rotará para estar encarado hacia el actor que desea vigilar. Overrides: object.__init__